@@ -277,11 +277,12 @@ get.edge.attribute <- function(graph, name, index = E(graph)) { # nocov start
 #' graph_attr(g, "name")
 graph_attr <- function(graph, name) {
   ensure_igraph(graph)
+
   if (missing(name)) {
-    graph.attributes(graph)
-  } else {
-    .Call(R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_graph)[[as.character(name)]]
+    return(graph.attributes(graph))
   }
+
+  .Call(R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_graph)[[as.character(name)]]
 }
 
 
@@ -348,10 +349,7 @@ graph.attributes <- function(graph) {
 #' @export
 "graph.attributes<-" <- function(graph, value) {
   ensure_igraph(graph)
-  if (!is.list(value) || (length(value) > 0 && is.null(names(value))) ||
-    any(names(value) == "") || any(duplicated(names(value)))) {
-    stop("Value must be a named list with unique names")
-  }
+  assert_named_list(value)
 
   .Call(R_igraph_mybracket2_set, graph, igraph_t_idx_attr, igraph_attr_idx_graph, value)
 }
@@ -382,20 +380,18 @@ vertex_attr <- function(graph, name, index = V(graph)) {
   ensure_igraph(graph)
   if (missing(name)) {
     if (missing(index)) {
-      vertex.attributes(graph)
-    } else {
-      vertex.attributes(graph, index = index)
-    }
-  } else {
-    myattr <-
-      .Call(R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_vertex)[[as.character(name)]]
-    if (is_complete_iterator(index)) {
-      myattr
-    } else {
-      index <- as_igraph_vs(graph, index)
-      myattr[index]
+      return(vertex.attributes(graph))
     }
+    return(vertex.attributes(graph, index = index))
   }
+  myattr <-
+    .Call(R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_vertex)[[as.character(name)]]
+  if (is_complete_iterator(index)) {
+    return(myattr)
+  }
+  index <- as_igraph_vs(graph, index)
+  myattr[index]
+
 }
 
 #' Set one or more vertex attributes
@@ -471,8 +467,6 @@ i_set_vertex_attr <- function(graph, name, index = V(graph), value, check = TRUE
     value <- as.numeric(value)
   }
 
-  single <- is_single_index(index)
-  complete <- is_complete_iterator(index)
   if (!missing(index) && check) {
     index <- as_igraph_vs(graph, index)
   }
@@ -480,10 +474,13 @@ i_set_vertex_attr <- function(graph, name, index = V(graph), value, check = TRUE
 
   vattrs <- .Call(R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_vertex)
 
-  if (!complete && !(name %in% names(vattrs))) {
+  complete <- is_complete_iterator(index)
+  name_available <- (name %in% names(vattrs))
+  if (!complete && !name_available) {
     vattrs[[name]] <- value[rep.int(NA_integer_, vcount(graph))]
   }
 
+  single <- is_single_index(index)
   if (single) {
     vattrs[[name]][[index]] <- value
   } else {
@@ -521,45 +518,47 @@ vertex.attributes <- function(graph, index = V(graph)) {
 
   res <- .Call(R_igraph_mybracket2_copy, graph, igraph_t_idx_attr, igraph_attr_idx_vertex)
 
-  if (!missing(index) &&
-    (length(index) != vcount(graph) || any(index != V(graph)))) {
-    for (i in seq_along(res)) {
-      res[[i]] <- res[[i]][index]
+  if (!missing(index)) {
+    index_is_natural_sequence <- (length(index) == vcount(graph) &&
+        identical(index, seq(1, vcount(graph))))
+    if  (!index_is_natural_sequence) {
+      for (i in seq_along(res)) {
+        res[[i]] <- res[[i]][index]
+      }
     }
   }
+
   res
 }
 
+set_value_at <- function(value, idx, length_out) {
+  out <- value[NULL]
+  length(out) <- length_out
+  out[idx] <- value
+  unname(out)
+}
+
 #' @export
 "vertex.attributes<-" <- function(graph, index = V(graph), value) {
   ensure_igraph(graph)
 
-  if (!is.list(value) || (length(value) > 0 && is.null(names(value))) ||
-    any(names(value) == "") || any(duplicated(names(value)))) {
-    stop("Value must be a named list with unique names")
-  }
-  if (any(sapply(value, length) != length(index))) {
+  assert_named_list(value)
+
+  if (!all(lengths(value) == length(index))) {
     stop("Invalid attribute value length, must match number of vertices")
   }
 
   if (!missing(index)) {
     index <- as_igraph_vs(graph, index)
 
-    if (any(duplicated(index)) || any(is.na(index))) {
+    if (anyDuplicated(index) || anyNA(index)) {
       stop("Invalid vertices in index")
     }
   }
 
-  if (!missing(index) &&
-    (length(index) != vcount(graph) || any(index != V(graph)))) {
-    vs <- V(graph)
-    for (i in seq_along(value)) {
-      tmp <- value[[i]]
-      length(tmp) <- 0
-      length(tmp) <- length(vs)
-      tmp[index] <- value[[i]]
-      value[[i]] <- tmp
-    }
+  index_is_natural_sequence <- (length(index) == vcount(graph) && all(index == V(graph)))
+  if (!missing(index) && !index_is_natural_sequence) {
+    value <- map(value, set_value_at, idx = index, length_out = length(V(graph)))
   }
 
   .Call(R_igraph_mybracket2_set, graph, igraph_t_idx_attr, igraph_attr_idx_vertex, value)
@@ -743,10 +742,8 @@ edge.attributes <- function(graph, index = E(graph)) {
 "edge.attributes<-" <- function(graph, index = E(graph), value) {
   ensure_igraph(graph)
 
-  if (!is.list(value) || (length(value) > 0 && is.null(names(value))) ||
-    any(names(value) == "") || any(duplicated(names(value)))) {
-    stop("Value must be a named list with unique names")
-  }
+  assert_named_list(value)
+
   if (any(sapply(value, length) != length(index))) {
     stop("Invalid attribute value length, must match number of edges")
   }
@@ -1031,7 +1028,7 @@ igraph.i.attribute.combination <- function(comb) {
     names(comb) <- rep("", length(comb))
   }
   if (any(duplicated(names(comb)))) {
-    warning("Some attributes are duplicated")
+    cli::cli_warn("Some attributes are duplicated")
   }
   comb <- lapply(comb, function(x) {
     if (!is.character(x)) {
@@ -1188,3 +1185,20 @@ NULL
 `$<-.igraph` <- function(x, name, value) {
   set_graph_attr(x, name, value)
 }
+
+assert_named_list <- function(value) {
+  error_msg <- "{.arg value} must be a named list with unique names"
+
+  if (!is.list(value)) {
+    rlang::abort(error_msg)
+  }
+
+  if (length(value) == 0) {
+    return()
+  }
+
+  if (!rlang::is_named(value) || anyDuplicated(names(value)) > 0) {
+
+    rlang::abort(error_msg)
+  }
+}
