@@ -11,40 +11,26 @@ test_that("cluster_leading_eigen works", {
     })
     ev <- eigen(M)
     ret <- 0
-    expect_that(ev$values[1], equals(value))
+    expect_equal(ev$values[1], value)
     if (sign(ev$vectors[1, 1]) != sign(vector[1])) {
       ev$vectors <- -ev$vectors
     }
-    expect_that(ev$vectors[, 1], equals(vector))
+    expect_equal(ev$vectors[, 1], vector)
     0
   }
 
   g <- make_graph("Zachary")
   lc <- cluster_leading_eigen(g, callback = f)
 
-  expect_that(lc$modularity, equals(modularity(g, lc$membership)))
-  expect_that(
+  expect_equal(lc$modularity, modularity(g, lc$membership))
+  expect_equal(
     as.vector(membership(lc)),
-    equals(c(
-      1, 3, 3, 3, 1, 1, 1, 3, 2, 2, 1, 1, 3, 3, 2, 2,
-      1, 3, 2, 3, 2, 3, 2, 4, 4, 4, 2, 4, 4, 2, 2, 4,
-      2, 2
-    ))
+    c(1, 3, 3, 3, 1, 1, 1, 3, 2, 2, 1, 1, 3, 3, 2, 2, 1, 3, 2, 3, 2, 3, 2, 4, 4, 4, 2, 4, 4, 2, 2, 4, 2, 2)
   )
-  expect_that(length(lc), equals(4))
-  expect_that(
+  expect_equal(length(lc), 4)
+  expect_equal(
     sizes(lc),
-    equals(structure(c(7L, 12L, 9L, 6L),
-      .Dim = 4L, .Dimnames =
-        structure(
-          list(
-            `Community sizes` =
-              c("1", "2", "3", "4")
-          ),
-          .Names = "Community sizes"
-        ),
-      class = "table"
-    ))
+    structure(c(7L, 12L, 9L, 6L), .Dim = 4L, .Dimnames = structure(list(`Community sizes` = c("1", "2", "3", "4")), .Names = "Community sizes"), class = "table")
   )
 
   ## Check that the modularity matrix is correct
@@ -59,12 +45,12 @@ test_that("cluster_leading_eigen works", {
     B <- A[myc, myc] - (deg[myc] %*% t(deg[myc])) / 2 / ec
     BG <- B - diag(rowSums(B))
 
-    expect_that(M, equals(BG))
+    expect_equal(M, BG)
     0
   }
 
   g <- make_graph("Zachary")
-  A <- as_adj(g, sparse = FALSE)
+  A <- as_adjacency_matrix(g, sparse = FALSE)
   ec <- ecount(g)
   deg <- degree(g)
   lc <- cluster_leading_eigen(g, callback = f)
@@ -77,9 +63,9 @@ test_that("cluster_leading_eigen works", {
     g <- sample_gnm(20, sample(5:40, 1))
     lec1 <- cluster_leading_eigen(g)
     lec2 <- cluster_leading_eigen(g)
-    expect_that(
+    expect_equal(
       as.vector(membership(lec1)),
-      equals(as.vector(membership(lec2)))
+      as.vector(membership(lec2))
     )
   }
 })
